from tw.api import CSSLink

blacktie_css = CSSLink(modname=__name__, filename='static/black-tie/jquery-ui-1.8.9.custom.css')
blitzer_css = CSSLink(modname=__name__, filename='static/blitzer/jquery-ui-1.8.9.custom.css')
cupertino_css = CSSLink(modname=__name__, filename='static/cupertino/jquery-ui-1.8.9.custom.css')
darkhive_css = CSSLink(modname=__name__, filename='static/dark-hive/jquery-ui-1.8.9.custom.css')
dotluv_css = CSSLink(modname=__name__, filename='static/dot-luv/jquery-ui-1.8.9.custom.css')
eggplant_css = CSSLink(modname=__name__, filename='static/eggplant/jquery-ui-1.8.9.custom.css')
excitebike_css = CSSLink(modname=__name__, filename='static/excite-bike/jquery-ui-1.8.9.custom.css')
flick_css = CSSLink(modname=__name__, filename='static/flick/jquery-ui-1.8.9.custom.css')
hotsneaks_css = CSSLink(modname=__name__, filename='static/hot-sneaks/jquery-ui-1.8.9.custom.css')
humanity_css = CSSLink(modname=__name__, filename='static/humanity/jquery-ui-1.8.9.custom.css')
lefrog_css = CSSLink(modname=__name__, filename='static/le-frog/jquery-ui-1.8.9.custom.css')
mintchoc_css = CSSLink(modname=__name__, filename='static/mint-choc/jquery-ui-1.8.9.custom.css')
overcast_css = CSSLink(modname=__name__, filename='static/overcast/jquery-ui-1.8.9.custom.css')
peppergrinder_css = CSSLink(modname=__name__, filename='static/pepper-grinder/jquery-ui-1.8.9.custom.css')
redmond_css = CSSLink(modname=__name__, filename='static/redmond/jquery-ui-1.8.9.custom.css')
smoothness_css = CSSLink(modname=__name__, filename='static/smoothness/jquery-ui-1.8.9.custom.css')
southstreet_css = CSSLink(modname=__name__, filename='static/south-street/jquery-ui-1.8.9.custom.css')
start_css = CSSLink(modname=__name__, filename='static/start/jquery-ui-1.8.9.custom.css')
sunny_css = CSSLink(modname=__name__, filename='static/sunny/jquery-ui-1.8.9.custom.css')
swankypurse_css = CSSLink(modname=__name__, filename='static/swanky-purse/jquery-ui-1.8.9.custom.css')
trontastic_css = CSSLink(modname=__name__, filename='static/trontastic/jquery-ui-1.8.9.custom.css')
uidarkness_css = CSSLink(modname=__name__, filename='static/ui-darkness/jquery-ui-1.8.9.custom.css')
uilightness_css = CSSLink(modname=__name__, filename='static/ui-lightness/jquery-ui-1.8.9.custom.css')
vader_css = CSSLink(modname=__name__, filename='static/vader/jquery-ui-1.8.9.custom.css')


# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__DISTRIBUTION__ = 'tw.uitheme'
__DESCRIPTION__ = 'theming for jquery plugins packaged as tosca widgets ressources, based on 1.8.9'
__URL__ = 'http://jqueryui.com/themeroller/'
__VERSION__ = '0.2.2'
__AUTHOR__ = 'Nicolas Laurance'
__EMAIL__ = 'nicolas[dot]laurance[at]gmail[dot]com'
__COPYRIGHT__ = "Copyright 2010 Nicolas Laurance"
__LICENSE__ = 'GPL'



import os
import sys

from setuptools import setup, find_packages

execfile(os.path.join("tw", "uitheme", "release.py"))

setup(
    name=__DISTRIBUTION__,
    version=__VERSION__,
    description=__DESCRIPTION__,
    author=__AUTHOR__,
    author_email=__EMAIL__,
    url=__URL__,
    install_requires=[
        "ToscaWidgets",
        ## Add other requirements here
        # "Genshi",
        ],
    packages=find_packages(exclude=['ez_setup', 'tests']),
    namespace_packages = ['tw'],
    zip_safe=False,
    include_package_data=True,
    test_suite = 'nose.collector',
    entry_points="""
    """,
    keywords = [
        'toscawidgets.widgets', 'css', 'jquery', 'theme'
    ],
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Environment :: Web Environment :: ToscaWidgets',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Widget Sets',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
)
